<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 * @package forestly
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;

	update_option( 'optionsframework', $optionsframework_settings );

}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 */

function optionsframework_options() {
/*
	// Test data
	$test_array = array(
		'one' => __('One', 'forestly'),
		'two' => __('Two', 'forestly'),
		'three' => __('Three', 'forestly'),
		'four' => __('Four', 'forestly'),
		'five' => __('Five', 'forestly')
	);

	// Multicheck Array
	$multicheck_array = array(
		'one' => __('French Toast', 'forestly'),
		'two' => __('Pancake', 'forestly'),
		'three' => __('Omelette', 'forestly'),
		'four' => __('Crepe', 'forestly'),
		'five' => __('Waffle', 'forestly')
	);

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );

	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/img/';

	$options = array();

	$options[] = array(
		'name' => __('Basic Settings', 'forestly'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Input Text Mini', 'forestly'),
		'desc' => __('A mini text input field.', 'forestly'),
		'id' => 'example_text_mini',
		'std' => 'Default',
		'class' => 'mini',
		'type' => 'text');

	$options[] = array(
		'name' => __('Input Text', 'forestly'),
		'desc' => __('A text input field.', 'forestly'),
		'id' => 'example_text',
		'std' => 'Default Value',
		'type' => 'text');

	$options[] = array(
		'name' => __('Textarea', 'forestly'),
		'desc' => __('Textarea description.', 'forestly'),
		'id' => 'example_textarea',
		'std' => 'Default Text',
		'type' => 'textarea');

	$options[] = array(
		'name' => __('Input Select Small', 'forestly'),
		'desc' => __('Small Select Box.', 'forestly'),
		'id' => 'example_select',
		'std' => 'three',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $test_array);

	$options[] = array(
		'name' => __('Input Select Wide', 'forestly'),
		'desc' => __('A wider select box.', 'forestly'),
		'id' => 'example_select_wide',
		'std' => 'two',
		'type' => 'select',
		'options' => $test_array);

	if ( $options_categories ) {
	$options[] = array(
		'name' => __('Select a Category', 'forestly'),
		'desc' => __('Passed an array of categories with cat_ID and cat_name', 'forestly'),
		'id' => 'example_select_categories',
		'type' => 'select',
		'options' => $options_categories);
	}

	if ( $options_tags ) {
	$options[] = array(
		'name' => __('Select a Tag', 'options_check'),
		'desc' => __('Passed an array of tags with term_id and term_name', 'options_check'),
		'id' => 'example_select_tags',
		'type' => 'select',
		'options' => $options_tags);
	}

	$options[] = array(
		'name' => __('Select a Page', 'forestly'),
		'desc' => __('Passed an pages with ID and post_title', 'forestly'),
		'id' => 'example_select_pages',
		'type' => 'select',
		'options' => $options_pages);

	$options[] = array(
		'name' => __('Input Radio (one)', 'forestly'),
		'desc' => __('Radio select with default options "one".', 'forestly'),
		'id' => 'example_radio',
		'std' => 'one',
		'type' => 'radio',
		'options' => $test_array);

	$options[] = array(
		'name' => __('Example Info', 'forestly'),
		'desc' => __('This is just some example information you can put in the panel.', 'forestly'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Input Checkbox', 'forestly'),
		'desc' => __('Example checkbox, defaults to true.', 'forestly'),
		'id' => 'example_checkbox',
		'std' => '1',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Advanced Settings', 'forestly'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Check to Show a Hidden Text Input', 'forestly'),
		'desc' => __('Click here and see what happens.', 'forestly'),
		'id' => 'example_showhidden',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Hidden Text Input', 'forestly'),
		'desc' => __('This option is hidden unless activated by a checkbox click.', 'forestly'),
		'id' => 'example_text_hidden',
		'std' => 'Hello',
		'class' => 'hidden',
		'type' => 'text');

	$options[] = array(
		'name' => __('Uploader Test', 'forestly'),
		'desc' => __('This creates a full size uploader that previews the image.', 'forestly'),
		'id' => 'example_uploader',
		'type' => 'upload');

	$options[] = array(
		'name' => "Example Image Selector",
		'desc' => "Images for layout.",
		'id' => "example_images",
		'std' => "2c-l-fixed",
		'type' => "images",
		'options' => array(
			'1col-fixed' => $imagepath . '1col.png',
			'2c-l-fixed' => $imagepath . '2cl.png',
			'2c-r-fixed' => $imagepath . '2cr.png')
	);

	$options[] = array(
		'name' =>  __('Example Background', 'forestly'),
		'desc' => __('Change the background CSS.', 'forestly'),
		'id' => 'example_background',
		'std' => $background_defaults,
		'type' => 'background' );

	$options[] = array(
		'name' => __('Multicheck', 'forestly'),
		'desc' => __('Multicheck description.', 'forestly'),
		'id' => 'example_multicheck',
		'std' => $multicheck_defaults, // These items get checked by default
		'type' => 'multicheck',
		'options' => $multicheck_array);

	$options[] = array(
		'name' => __('Colorpicker', 'forestly'),
		'desc' => __('No color selected by default.', 'forestly'),
		'id' => 'example_colorpicker',
		'std' => '',
		'type' => 'color' );

	$options[] = array( 'name' => __('Typography', 'forestly'),
		'desc' => __('Example typography.', 'forestly'),
		'id' => "example_typography",
		'std' => $typography_defaults,
		'type' => 'typography' );

	$options[] = array(
		'name' => __('Custom Typography', 'forestly'),
		'desc' => __('Custom typography options.', 'forestly'),
		'id' => "custom_typography",
		'std' => $typography_defaults,
		'type' => 'typography',
		'options' => $typography_options );

	$options[] = array(
		'name' => __('Text Editor', 'forestly'),
		'type' => 'heading' );

	
	 // For $settings options see:
	 // http://codex.wordpress.org/Function_Reference/wp_editor
	 //
	 // 'media_buttons' are not supported as there is no post to attach items to
	 // 'textarea_name' is set by the 'id' you choose
	 

	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	$options[] = array(
		'name' => __('Default Text Editor', 'forestly'),
		'desc' => sprintf( __( 'You can also pass settings to the editor.  Read more about wp_editor in <a href="%1$s"
		* target="_blank">the WordPress codex</a>', 'forestly' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'example_editor',
		'type' => 'editor',
		'settings' => $wp_editor_settings );
*/

////////////////////////////////////////////////////////////////////////
///////////////////////                          ///////////////////////
///////////////////////   <<    References       ///////////////////////
///////////////////////      Own Options    >>   ///////////////////////
///////////////////////                          ///////////////////////
////////////////////////////////////////////////////////////////////////

// GENERAL TAB DATA: ---------------------------------------------------



// DESIGN TAB DATA: ----------------------------------------------------

	// If using image radio buttons, define a directory path
	$forestly_pre_design_imagepath =  get_template_directory_uri() . '/img/';

// SOCIAL TAB DATA: ----------------------------------------------------

	// Social Network Types Array (Icons)
	$social_icons_array = array(
		'blogger' => __('Blogger', 'forestly'),
		'delicious' => __('Delicious', 'forestly'),
		'digg' => __('Digg', 'forestly'),
		'facebook' => __('Facebook', 'forestly'),
		'flickr' => __('Flickr', 'forestly'),
		'google' => __('Google', 'forestly'),
		'gplus' => __('Google Plus', 'forestly'),
		'lastfm' => __('Lastfm', 'forestly'),
		'linkedin' => __('LinkedIn', 'forestly'),
		'myspace' => __('MySpace', 'forestly'),
		'orkut' => __('Orkut', 'forestly'),
		'reddit' => __('Reddit', 'forestly'),
		'rss' => __('RSS', 'forestly'),
		'skype' => __('Skype', 'forestly'),
		'stumbleupon' => __('Stumbleupon', 'forestly'),
		'technorati' => __('Technorati', 'forestly'),
		'twitter' => __('Twitter', 'forestly'),
		'vimeo' => __('Vimeo', 'forestly'),
		'wordpress' => __('WordPress', 'forestly'),
		'yahoo' => __('Yahoo', 'forestly'),
		'youtube' => __('Youtube', 'forestly')
	);

	// Set Link for the RSS Social Media Icon
	$forestly_default_rss_link = esc_url( home_url( '/' ) ).'?feed=rss2';

// MISCELLANEOUS TAB DATA: ---------------------------------------------



// HELP TAB DATA: ------------------------------------------------------

	// Define Links for the Help Text
	$forestly_more_themes_url = 'http://www.fosforito.net/wp-themes/';
	$forestly_forestly_forum_url = 'http://www.fosforito.net/forums/forum/forestly/';
	$forestly_fosforito_media_url = 'http://www.fosforito.net/';
	$forestly_support_forums_url = 'http://www.fosforito.net/forums/';



//----------------------------------------------------------------------
//----------------------------------------------------------------------

// GENERAL TAB OPTIONS: ------------------------------------------------

	$options[] = array(
		'name' => __('General', 'forestly'),
		'type' => 'heading' );

	$options[] = array(
		'desc' => __('Edit general options about your Website in this section.', 'forestly'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Set Logo', 'forestly'),
		'desc' => __('Select or upload a new Logo Image to replace the Website Title and Description.', 'forestly'),
		'id' => 'logo_image',
		'type' => 'upload');
		
	$options[] = array(
		'name' => __('Set Favicon Icon', 'forestly'),
		'desc' => __('Select or upload a new Favicon Icon to display in the Address Bar of the Browser next to the Website Title. The size of the Icon should be of 16x16px.', 'forestly'),
		'id' => 'favicon_icon',
		'type' => 'upload');

	$options[] = array(
		'name' => __('Post Excerpts', 'forestly'),
		'desc' => __('Check the Pages and Post Types where you want to display Post Excerpts.<br/>Leave unchecked to display complete Posts.', 'forestly'),
		'type' => 'info');

	$options[] = array(
		'desc' => __('Homepage', 'forestly'),
		'id' => 'activate_excerpts_on_home',
		'std' => '0',
		'type' => 'checkbox');

	$options[] = array(
		'desc' => __('Category Pages', 'forestly'),
		'id' => 'activate_excerpts_on_category',
		'std' => '1',
		'type' => 'checkbox');

	$options[] = array(
		'desc' => __('Tag Pages', 'forestly'),
		'id' => 'activate_excerpts_on_tag',
		'std' => '1',
		'type' => 'checkbox');
		
	$options[] = array(
		'desc' => __('Search Results Page', 'forestly'),
		'id' => 'activate_excerpts_on_search',
		'std' => '1',
		'type' => 'checkbox');

	$options[] = array(
		'desc' => __('Sticky Posts in Homepage', 'forestly'),
		'id' => 'activate_excerpts_on_sticky',
		'std' => '1',
		'type' => 'checkbox');
		


// DESIGN TAB OPTIONS: -------------------------------------------------

	$options[] = array(
		'name' => __('Design', 'forestly'),
		'type' => 'heading' );

	$options[] = array(
		'desc' => __('Please go to <a href="./customize.php">This Page</a> to change the backround image and background color of your Website.', 'forestly'),
		'type' => 'info');

	$options[] = array(
		'name' => __("Predefined Color Schemes", "forestly"),
		'desc' => __("Select a Color Scheme for your Website. For more customization you can add and modify your own CSS rules in the Miscellaneous Tab. If you need help related to custom CSS, go to the Help Tab or visit our official Support Forum.", "forestly"),
		'id' => "forestly_pre_design",
		'std' => "pre_forest",
		'type' => "images",
		'options' => array(
			'pre_forest' => $forestly_pre_design_imagepath . 'pre_forest.png',
			'pre_orange' => $forestly_pre_design_imagepath . 'pre_orange.png',
			'pre_bluesky' => $forestly_pre_design_imagepath . 'pre_bluesky.png',
			'pre_blackwhite' => $forestly_pre_design_imagepath . 'pre_blackwhite.png',
			'pre_grape' => $forestly_pre_design_imagepath . 'pre_grape.png',
			'pre_puppy' => $forestly_pre_design_imagepath . 'pre_puppy.png'
			)
	);

// SOCIAL TAB OPTIONS: -------------------------------------------------

	$options[] = array(
		'name' => __('Social', 'forestly'),
		'type' => 'heading' );

	$options[] = array(
		'desc' => __('Here you can activate and modify the Social Media Icons and URLs to be displayed in the Header Section of your Website. Leave an URL field blank to hide it\'s Icon.', 'forestly'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Display Social Media Links', 'forestly'),
		'desc' => __('Check if you want to display Social Media Links in the Website Header.', 'forestly'),
		'id' => 'enable_social_links',
		'std' => '1',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Open Links in new Tab', 'forestly'),
		'desc' => __('Check to open Social Media Links in a new Browser Tab.', 'forestly'),
		'id' => 'social_open_in_new_tab',
		'std' => '0',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Social Icon 1', 'forestly'),
		'desc' => __('Select a Social Media Icon.', 'forestly'),
		'id' => 'social_url_1_type',
		'std' => 'blogger',
		'type' => 'select',
		'class' => 'tiny',
		'options' => $social_icons_array );

	$options[] = array(
		'name' => __('URL for Icon 1', 'forestly'),
		'desc' => __('Provide an URL for the Icon.', 'forestly'),
		'id' => 'social_url_1',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Social Icon 2', 'forestly'),
		'desc' => __('Select a Social Media Icon.', 'forestly'),
		'id' => 'social_url_2_type',
		'std' => 'blogger',
		'type' => 'select',
		'class' => 'tiny',
		'options' => $social_icons_array );

	$options[] = array(
		'name' => __('URL for Icon 2', 'forestly'),
		'desc' => __('Provide an URL for the Icon.', 'forestly'),
		'id' => 'social_url_2',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Social Icon 3', 'forestly'),
		'desc' => __('Select a Social Media Icon.', 'forestly'),
		'id' => 'social_url_3_type',
		'std' => 'blogger',
		'type' => 'select',
		'class' => 'tiny',
		'options' => $social_icons_array );

	$options[] = array(
		'name' => __('URL for Icon 3', 'forestly'),
		'desc' => __('Provide an URL for the Icon.', 'forestly'),
		'id' => 'social_url_3',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Social Icon 4', 'forestly'),
		'desc' => __('Select a Social Media Icon.', 'forestly'),
		'id' => 'social_url_4_type',
		'std' => 'blogger',
		'type' => 'select',
		'class' => 'tiny',
		'options' => $social_icons_array );

	$options[] = array(
		'name' => __('URL for Icon 4', 'forestly'),
		'desc' => __('Provide an URL for the Icon.', 'forestly'),
		'id' => 'social_url_4',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Social Icon 5', 'forestly'),
		'desc' => __('Select a Social Media Icon.', 'forestly'),
		'id' => 'social_url_5_type',
		'std' => 'blogger',
		'type' => 'select',
		'class' => 'tiny',
		'options' => $social_icons_array );

	$options[] = array(
		'name' => __('URL for Icon 5', 'forestly'),
		'desc' => __('Provide an URL for the Icon.', 'forestly'),
		'id' => 'social_url_5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Social Icon 6', 'forestly'),
		'desc' => __('Select a Social Media Icon.', 'forestly'),
		'id' => 'social_url_6_type',
		'std' => 'rss',
		'type' => 'select',
		'class' => 'tiny',
		'options' => $social_icons_array );

	$options[] = array(
		'name' => __('URL for Icon 6', 'forestly'),
		'desc' => __('Provide an URL for the Icon.', 'forestly'),
		'id' => 'social_url_6',
		'std' => $forestly_default_rss_link,
		'type' => 'text');



// MISCELLANEOUS TAB OPTIONS: ------------------------------------------

	$options[] = array(
		'name' => __('Miscellaneous', 'forestly'),
		'type' => 'heading' );

	$options[] = array(
		'desc' => __('In this Section you can modify the Footer of your Website, edit custom CSS Styles and customize
		other miscellaneous Things.', 'forestly'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Custom Footer Text Left', 'forestly'),
		'desc' => __('Insert here the HTML you want to display in the Footer on the Left: Copyright Owner, Company Name, Year, etc...', 'forestly'),
		'id' => 'custom_footer_text_left',
		'std' => '&copy; 2014 &middot; All Rights reserved',
		'type' => 'textarea');

	$options[] = array(
		'name' => __('Custom Footer Text Right', 'forestly'),
		'desc' => __('Insert here the HTML you want to display in the Footer on the Right: Contact-, Terms & Conditions-, Privacy Policy Links, etc...', 'forestly'),
		'id' => 'custom_footer_text_right',
		'std' => '',
		'type' => 'textarea');

	$options[] = array(
		'name' => __('Custom CSS Styles', 'forestly'),
		'desc' => __('Insert here your custom CSS styles and include them in your Posts and Pages for more personalization.', 'forestly'),
		'id' => 'custom_css',
		'std' => '.site-header {
    background-color: #fff;
}',
		'type' => 'textarea');



// HELP TAB OPTIONS: ---------------------------------------------------

	$options[] = array(
		'name' => __('Help', 'forestly'),
		'type' => 'heading' );

	$options[] = array(
		'desc' => '
			<div style="background:#FFFFFF;float:right;padding:10px 0px 10px 30px; border-left:1px solid #e1e1e1;
			margin:10px;max-width:41%;">
			<h4><a style="text-decoration:none;" href="'.$forestly_more_themes_url.'">'.__('&raquo; More Themes', 'forestly').'</a></h4>
			<h4><a style="text-decoration:none;" href="'.$forestly_forestly_forum_url.'">'.__('&raquo; Support Forum', 'forestly').'</a></h4>
			<h4><a style="text-decoration:none;" href="'.$forestly_fosforito_media_url.'">'.__('&raquo; Fosforito.Net', 'forestly').'</a></h4>
			<br/>
			</div>
			'.__('<h2>Forestly Quick Start Guide</h2>', 'forestly').'
			'.__('<h3>Responsive Menu</h3><p>This is the first step: Set the Main Navigation menu for mobile view by going to <a href="./customize.php">This Page</a>. Create your WordPress menu as per your requirement and select it as <b>Main Navigation Menu</b>, Navigation Menu responsiveness won\'t work otherwise.</p>', 'forestly').'
			'.__('<h3>First things to do</h3><p>First upload a Logo Image for your Website. Than customize the Footer Texts in the "Miscellaneous" Section of this page and start Blogging! The Sidebar is Widget ready for easy configuration.</p>', 'forestly').' 
			'.__('<h3>Logo Size</h3><p>The recommended Logo should have dimensions of 200 x 55 pixels or similar. You can easily try uploading logos of different sizes via live customizer.</p>', 'forestly').'
			'.__('<h3>Safe Customization</h3><p>Forestly has the option to create custom CSS classes. You can add your own styles on this page in the "Miscellaneous" Section and include them in your Posts and Pages.</p><p>The unique limit is your own creativity!</p>', 'forestly').'
			'.__('<h3>Idea Behind Forestly</h3><p>The Idea behind Forestly is to equip the bloggers with a simple, light and fully responsive theme so	that they don\'t have to look anywhere else.</p><p>It has been designed and coded in such a way that even if you are new to Wordpress you will be able to make the most out of it.</p>', 'forestly').'
			'.__('<h3>Forestly is Safe</h3><p>Forestly uses Wordpress native funtions to generate thumbnails without relying on third party scripts such as timthumb. Forestly is also properly coded to avoid plugin conflicts and is customizable.</p>', 'forestly').'
			'.__('<h3>Built for Speed</h3><p>The first thing you will notice about Forestly is its blazing fast rendering, it will be loved by your visitors and they will have more time for browsing your content.', 'forestly').'
			'.__('<h3>The Right Choice - Ultra Responsive</h3><p>Forestly is a premium quality theme with pixel perfect typography and responsiveness and is built for speed with pagespeed score of 95+! Forestly implements proper SEO so that your content will rank high and is compatible with AIOSEO and Yoast SEO. It utilizes latest HTML5 and CSS3 for creating the awesomeness that looks good on every browser and is future ready.</p>', 'forestly').'
			'.__('<h3>Support</h3><p>Support is free, access our official Support Forums on www.fosforito.net/forums/. You can also report issues and feedback and help us in improving the theme.</p>', 'forestly').'
			'.__('<h3>Further Development and Roadmap</h3><p>Forestly has been handcrafted with most care and love, we hope that you will love this theme, kindly support us by rating the theme 5 stars, if there are any issue/bugs simply head to our Forums to report them and we will	do our best to fix those issues.</p>', 'forestly').'
			<br/><br/>
			'.__('Based on your feedback we will add the most wanted features for further improvement.', 'forestly').'
			<br/>
			'.__('This is just the beginning.', 'forestly').'
			<br/>
			- Jens Wagner
			'.__('Forestly Developer', 'forestly').'
			<br/><br/>
			&copy; 2014 <a href="'.$forestly_fosforito_media_url.'">Fosforito Media</a>.',
		'type' => 'info');



// END -----------------------------------------------------------------

	return $options;
	
}
